@@ -9,13 +9,12 @@ from vulture import Vulture
 v = Vulture()
 
 v.visit_arg
+v.visit_alias
 v.visit_Assign
 v.visit_Attribute
 v.visit_ClassDef
 v.visit_comprehension
 v.visit_For
 v.visit_FunctionDef
-v.visit_Import
-v.visit_ImportFrom
 v.visit_Name
 v.visit_Str
